aboutsummaryrefslogtreecommitdiff
path: root/filesystem/filesystem.go
diff options
context:
space:
mode:
authorEric Biggers <ebiggers@google.com>2019-10-29 00:04:39 -0700
committerEric Biggers <ebiggers@google.com>2019-10-29 00:04:39 -0700
commit249259376da98d8e10e6876c80ff3905e9756bdc (patch)
treea0bd6a5f79e04f369d2e6a4732d10d5a191826dd /filesystem/filesystem.go
parenta3434e41bd482fc1b35703f66c24c9d1ec3b0be2 (diff)
filesystem: rename Mount.Filesystem to Mount.FilesystemType
Make it clear that this refers to a type of filesystem such as "ext4", rather than to a specific filesystem instance.
Diffstat (limited to 'filesystem/filesystem.go')
-rw-r--r--filesystem/filesystem.go22
1 files changed, 11 insertions, 11 deletions
diff --git a/filesystem/filesystem.go b/filesystem/filesystem.go
index ee332c8..3884e6e 100644
--- a/filesystem/filesystem.go
+++ b/filesystem/filesystem.go
@@ -64,10 +64,10 @@ var (
)
// Mount contains information for a specific mounted filesystem.
// Path - Absolute path where the directory is mounted
// Filesystem - Name of the mounted filesystem
// Options - List of options used when mounting the filesystem
// Device - Device for filesystem (empty string if we cannot find one)
//
// In order to use a Mount to store fscrypt metadata, some directories must be
// setup first. Specifically, the directories created look like:
@@ -90,10 +90,10 @@ var (
// allows login protectors to be created when the root filesystem is read-only,
// provided that "/.fscrypt" is a symlink pointing to a writable location.
type Mount struct {
- Path string
- Filesystem string
- Options []string
- Device string
+ Path string
+ FilesystemType string
+ Options []string
+ Device string
}
// PathSorter allows mounts to be sorted by Path.
@@ -123,9 +123,9 @@ const (
func (m *Mount) String() string {
return fmt.Sprintf(`%s
- Filsystem: %s
- Options: %v
- Device: %s`, m.Path, m.Filesystem, m.Options, m.Device)
+ FilesystemType: %s
+ Options: %v
+ Device: %s`, m.Path, m.FilesystemType, m.Options, m.Device)
}
// BaseDir returns the path to the base fscrypt directory for this filesystem.
@@ -64,10 +64,10 @@ var (
)
// Mount contains information for a specific mounted filesystem.
-// Path - Absolute path where the directory is mounted
-// Filesystem - Name of the mounted filesystem
-// Options - List of options used when mounting the filesystem
-// Device - Device for filesystem (empty string if we cannot find one)
+// Path - Absolute path where the directory is mounted
+// FilesystemType - Type of the mounted filesystem, e.g. "ext4"
+// Options - List of options used when mounting the filesystem
+// Device - Device for filesystem (empty string if we cannot find one)
//
// In order to use a Mount to store fscrypt metadata, some directories must be